Faro de Vigo, noticias y actualidad de Vigo
Author: Faro de Vigo
Description: Noticias de última hora de Vigo, todas las noticias de hoy y la actualidad al instante. Lo que necesitas saber para estar informado de la actualidad de Vigo
Keywords: vigo, noticia vigo, Noticias de vigo, noticias vigo, Gran Vigo, hoy vigo, concello, Faro de vigo, últimas noticias, ultimas noticias, periodico, periódico, prensa, diario, noticia, noticias, noticias hoy vigo, noticias de hoy vigo, ultimas noticias vigo, ultima hora, última hora, tui, porriño, baiona, redondela , ponteareas, soutomaior, pazos de borbén, fornelos de montes, gondomar, nigrán, oia, o rosal, a guarda, tomiño, salceda de caselas, mos, a cañiza, as neves, crecente, covelo, arbo, salvaterra, mondariz, concello

#

Vigo
13 / 4º
GALICIA

## Todos los policías llevarán chaleco antes de seis meses

2 comentarios

La DGP anuncia que los agentes portarán esta prenda antes de que acaba el primer semestre de 2015

- El SUP pide a Fiscalía que investigue los chalecos femeninos sin repartir en Vigo

ECONOMÍA

## La justicia europea garantiza la legalidad del nuevo ´tax lease´

#### josé carneiro

| 1 comentario

El Tribunal de la UE rechaza el recurso de los astilleros holandeses contra el nuevo régimen fiscal español

ESPAÑA Caso Nóos

## El fiscal solicita aplicar la 'doctrina Botín' a la Infanta

2 comentarios

Horrach ve a Doña Cristina en "posición de indefensión" - Solicita 19 años de cárcel para Iñaki Urdangarin

- La Infanta pagará la fianza que pide el fiscal
- Horrach pide once años de prisión para Matas
- Gráfico: Las peticiones de condenas de la Fiscalía

- Gráfico: Así operaba el Instituto Nóos
- Los imputados
- Consulta el escrito del fiscal (pdf)
- Anexos al escrito

TECNOLOGÍA Transporte

## Uber mantendrá sus servicios en España pese al fallo

Comentar

Considera el cese "incompatible con el amplio reconocimiento político a los beneficios de compartir recursos"

- Un juez ordena el cese de actividades de Uber

ESPAÑA Poder Judicial

## El CGPJ permite a Ruz seguir con la instrucción de 'Gürtel'

Comentar

La comisión permanente saca a concurso su plaza pero le permite quedarse en calidad de refuerzo si lo pide

GRAN VIGO

## La dirección de Podemos coloca listas afines en Vigo, Ourense, A Coruña y Ferrol

Comentar

Galicia cuenta con 232 candidaturas para secretario general o miembro del consejo ciudadano en las 7 principales urbes, Narón y Vilagarcía de Arousa

AROUSA
Niños de Cambados durante la celebración del Día das Letras Galegas. // Iñaki Abella

## Solo el 23% de los vecinos de la comarca declara que habla habitualmente en gallego

#### m. gonzález | o salnés

| Comentar

Un estudio de la Xunta apunta que hay 24.667 hogares en los que ninguno de sus miembros se expresa en gallego

GALICIA

## De 3 a 11 años de cárcel para dos miembros de Resistencia Galega por atentar en Vigo

Comentar

Por colocar el 3 de agosto de 2012 dos artefactos en Sampaio, que destrozaron antenas de radio y telefonía

MUNDO Informe del Senado

## Así torturaba la CIA a los supuestos terroristas

Comentar

Alimentación e hidratación rectal, o ahogamiento simulado eran algunas de las prácticas llevadas a cabo

- La CIA actuó de un modo ´más brutal´ de lo que informó
- Obama: "Las torturas no ayudan contra el terrorismo"

DEPORTES
El celtismo, afición ejemplar en el fútbol español // M. G. BREA

### El Celta presume de afición

#### carlos i. castrillón

| Comentar

El club vigués anuncia la entrada de la nueva normativa y destaca el comportamiento del celtismo estos años

- Twitter se ríe de las sanciones a los cánticos ofensivos
- Interior releva a los coordinadores de seguridad de Atlético y Dépor
- Los aficionados recibirán un listado de cánticos prohibidos

DEPORTES

### Sergio Álvarez. "No hay ansiedad"

Comentar

El portero afirma que el vestuario "más que ansioso, está con ganas de volver a ganar por las últimas derrotas"

- El ojo que todo lo mira
- Los técnicos, piezas claves en el sistema
- Nolito: "Lo que hizo Cristiano Ronaldo no es juego limpio"
- Jonny reclama sanciones para quienes simulen caídas
- El futuro del celtismo invade Balaídos

DEPORTES PONTEVEDRA
Edu Sousa durante un entrenamiento en A Xunqueira. // Rafa Vázquez

### Edu Sousa: "Siempre miro a los lanzadores y en este caso noté que tenían dudas "

Comentar

"Es extraño que te piten dos penaltis en casa, pero tuve la fortuna de neutralizar sus lanzamientos"

- "En un penalti el lanzador tiene más que perder"

TECNOLOGÍA Operación policial

### La web The Pirate Bay, caída tras una redada policial

Comentar

La policía sueca irrumpió en la sede de la página de enlaces para descargas y confiscó sus servidores

DEPORTES Champions League
Ver Galería

Juventus | 0 | 0 | Atlético

### El Atlético sella el primer puesto

Comentar

Los colchoneros controlaron el partido y frenaron la ambición de la 'Juve', que se clasifica como segunda

- Simeone: "Buscamos lo que nos convenía"
- Basilea y Mónaco dejan fuera a Liverpool y Zenit

- Estadísticas: Solo tres remates del Atlético a puerta
- Champions League: Clasificación y resultados

PONTEVEDRA

### Otro libro insiste en la teoría del origen gallego de Cristóbal Colón

2 comentarios

Su autor, Ángel Carracelas, defiende que el pontevedrés Pedro Madruga es el álter ego del descubridor de América

SOCIEDAD Y CULTURA

### Suárez-Llanos, profeta en su tierra

#### ágatha de santos | vigo

| Comentar

"A esmorga" es la primera película en España para el director de fotografía vigués

- Tras los pasos de ´A Esmorga´

AROUSA

### El séptimo arte de trabajar el mar

#### redacción | arousa

| Comentar

Varias entidades presentan un documental en el que se presentan impactantes imágenes submarinas

SUCESOS

### La menor que se prostituía en Padrón dice que fue coaccionada

Comentar

La joven, de 14 años, afirma que tanto ella como su madre están siendo "amenazadas" por la familia del imputado rumano

#### Más noticias

- #### Los trabajadores de mantenimiento del Meixoeiro suspenden la huelga

- #### Retiran el carné al padre que dejó conducir a su hijo menor en Rande

## Salud

Pastora Soler en Eurovisión 2012

### Pánico escénico: qué es y cómo se puede superar

Comentar

Este trastorno puede durar para todo la vida si no se trata con la ayuda de un psicólogo

### Alérgicos: 5 consejos para evitar sustos en Navidad

Los turrones, el marisco, la nieve artificial o incluso el árbol pueden convertirse en productos...

### La gripe, otro ´regalo´ que también trae la Navidad

Este virus, que afecta a un 15% de la población, causó la muerte de más de 1.500 personas el año...

### Cómo evitar el dolor de oídos si viajas en avión

Te damos unas pautas para que los cambios de presión al volar no causen problemas a tus oídos

Todas las noticias de Salud

## Cine

- Noticias
- Cartelera
- Críticas de cine
- Estrenos

El buceo es un atractivo turístico en la ría de Arousa. // Iñaki Abella

### El séptimo arte de trabajar el mar

Comentar

Varias entidades presentan un documental en el que se presentan impactantes imágenes submarinas

### ´Mil noches, una boda´: Realidad y ficción en armonía

La historia interesa y se consolida con cimientos bien elaborados, motivo por el cual fue...

### Lucas aún no ha visto el tráiler de ´Star Wars VII: El despertar de la Fuerza´

"No sé nada al respecto, todavía no he visto nada", dijo Lucas al ser interrogado por el tráiler...

### El actor Mark Wahlberg pide perdón por su historial delictivo

"No me he comprometido con causas filantrópicas para que la gente olvide mi pasado", se defiende

El buceo es un atractivo turístico en la ría de Arousa. // Iñaki Abella

### El séptimo arte de trabajar el mar

Comentar

Varias entidades presentan un documental en el que se presentan impactantes imágenes submarinas

### Lucas aún no ha visto el tráiler de ´Star Wars VII: El despertar de la Fuerza´

"No sé nada al respecto, todavía no he visto nada", dijo Lucas al ser interrogado por el tráiler...

### El actor Mark Wahlberg pide perdón por su historial delictivo

"No me he comprometido con causas filantrópicas para que la gente olvide mi pasado", se defiende

### ¿Es ´Frozen´ la versión Disney de ´El resplandor´ de Kubrick?

La teoría viene de la blogger Mary Katharine Ham, quien empezó a sentir algo extraño cuando vio...

Un fotograma de la película.

### ´Mil noches, una boda´: Realidad y ficción en armonía

Comentar

La historia interesa y se consolida con cimientos bien elaborados, motivo por el cual fue...

### ´Los pingüinos de Madagascar´: Imaginación pasada de rosca

La cinta ha contado, y eso se nota, con la experiencia de un realizador tan curtido en la materia...

### ´Fuego´: Con el terrorismo a cuestas

El escritor y director Luis Marías logra crear un marco no exento de convicción, pero sin la...

### ´Mortadelo y Filemón´: Con el sabor único del original

Divertida, brillante, con un inusual talante creativo y con un guión que es plenamente coherente...

Todas las noticias de Cine

## Gente

Paula Echevarría y David Bustamante.

### Paula Echevarría: ´David y yo somos un matrimonio normal´

Comentar

"Nunca hemos intentado vender una imagen de ensueño", dice la actriz, satisfecha con su relación

### La correspondencia de Marilyn, un buen negocio

| Una carta de amor de la estrella del béisbol Joe DiMaggio a Marilyn Monroe ha sido vendida por...

### La duquesa Catalina reina en Nueva York

La esposa del príncipe Guillermo visita un centro de atención a la infancia del barrio de Harlem

### La Scala despide al ´grandísimo´ Barenboim

El director Daniel Barenboim se despidió el pasado sábado de La Scala de Milán con una nueva...

Todas las noticias de Gente

## Videojuegos

'Total War Battles: Kingdom'.

### ´Total War Battles: Kingdom´, la nueva apuesta gratuita de SEGA

Comentar

Ambientado en los inicios del siglo X, el juego combina la construcción de un reino con batallas...

### Primeras imágenes y detalles de ´Assassin´s Creed Victory´

La próxima entrega de la saga llegará en 2015 y estará ambientada en el Londres victoriano

### Veinte años de la PlayStation

En diciembre de 1994 Sony puso a la venta la que sería la consola que cambiaría el mundo de los...

### ´The Legend of Zelda U´ y su mundo abierto

Nintendo recupera y da una vuelta de tuerca a uno de sus juegos más icónicos y con más seguidores

Todas las noticias de Videojuegos

## Motor

Ferrari Sergio: sólo 6 unidades

### Ferrari Sergio: sólo 6 unidades

La marca italiana saca una producción limitada de seis unidades del Ferrari Sergio, un modelo que rinde homenaje a los 60...

### Éxito de la manifestación en contra de los guardarraíles

El pasado sábado Madrid fue inundada por motos procedentes de toda España unidas por un mismo lema: "Por una Administración...

### Un año sin Javier Herrero: le recordamos con sus editoriales

El día 21 de diciembre se cumple el primer aniversario del fallecimiento de Javier Herrero. Durante los próximos días...

### Prueba del nuevo smart fortwo 2015

Después de 16 años en el mercado y tres generaciones, smart presenta su nuevo fortwo, un modelo urbano que mejora en todo...

Todas las noticias de Motor

## Agenda

- Agenda
- Conciertos
- Espectáculos
- Teatro

El recinto ferial silledense, lleno por el Closing Tour 2014

### 7.000 fieles al Closing Tour

Comentar

La venta de entradas se prolongó hasta la madrugada »Durante las nueve horas del espectáculo, las...

### Dismal, premio PontevedraFerve

El jurado le da el galardón honorífico a la banda pontevedresa por su trayectoria

### Vilagarcía celebra la Navidad con teatro y festivales

El centro cultural está ocupado los fines de semana de diciembre »Hay un calendario especial para...

### Más de 10.000 pequeñas almas visitan Megaxove

» Jugadores del COB firmaron autógrafos en el recinto ferial » El futbolín humano, una de las...

Todas las noticias de Agenda

## Gastronomía

El centollo es el marisco más emblemático de O Grove. // Muñiz

### Satisfactorias Xornadas da Centola en O Grove

Comentar

» Algunas marisquerías afirman que el nivel de ventas incluso es superior al de 2013 »El día de...

### Cobideza, un nuevo queso en el mercado

La cooperativa repartirá entre sus socios, a modo de presente navideño, 200 unidades elaboradas...

### La matanza llega con el frío

Muchos dezanos aprovechan la festividad de la Constitución y la Inmaculada para realizar el...

### Catas abiertas para disfrutar los Rías Baixas

Salvaterra ultima la fiesta de los espumosos para las jornadas que se celebran los días 20 y 21 de...

Todas las noticias de Gastronomía
HEMEROTECA
Volver a la Edición Actual

- Antes
  26,50€ -43% 15€

  #### Nido Comida en Movimiento

  Comida a domicilio para 2

Más ofertas en cuponisimo.farodevigo.es
El tiempo en Vigo
¿Lucirá el sol en Vigo, lloverá? ¿Qué me pongo?
¿Te plantas cada día frente al armario sin saber qué ponerte? FarodeVigo.es, WhatoWeather y 4gotas.com te ayudan a elegir modelo para que la meteorología no te sorprenda.

Martes

## Escolares sobre ruedas

La ANPA Magonia de la Escola Villalaura impulsa la actividad deportiva fuera del horario académico

## Teatro para la solidaridad

La compañía A Tropa de Trato escenifica la obra "Antía, Wamba e o regato pequeno"

## Fina Casalderrey, en el Pena de Francia

La escritora defiende la sensibilidad como imprescindible para escribir

## Babyolimpiada en Acacias

Una jornada dedicada a la promoción del deporte y la actividad física entre los alumnos de...

## Álex Quintá, premio gallego de ´¿Qué es un rey para ti?´

Alejandro Quintá recibe el galardón de manos de Felipe VI por su maqueta

## Suscriptor | Opinión

Contenido exclusivo para suscriptores digitales

#### FERNANDO FRANCO

#### En el día de las conchas

¡Oh, Dios mío, llego a Vigo el domingo noche, para descansar el lunes, día de las conchas y de la patrona de la Infantería española (y antes de los...

#### JOAQUÍN RÁBAGO

#### Autoexplotación

En una de sus diarias viñetas sintetizaba El Roto el modelo laboral que está implantando el nuevo capitalismo. Mostraba a un hombre anuncio que...

#### PEDRO DE SILVA

#### Las nutrias

En mi ciudad, el gobierno local (derecha) ha acordado con el autonómico (izquierda) crear una comisión para frenar los ataques de las nutrias...

#### JOSÉ MANUEL PONTE

#### Por una nueva Constitución

Como era previsible, el aniversario de la Constitución de 1978, que ya tiene una vigencia de 36 años, se celebró con continuas invocaciones a la...

#### G. GARCÍA-ALCALDE

#### La hucha saqueada

Al ritmo que llevan los saqueos, la "hucha" de las pensiones no tardará en convertirse en cuenta de adeudos con un pie sobre la quiebra. Nada menos...

#### MANUEL BRAGADO

#### Os dereitos da infancia

O pasado 20 de novembro, día mundial da infancia, celebrouse o vinte e cinco aniversario da "Convención sobre os dereitos do neno" (CDN) aprobada...

## Televisión

Imagen del reportero con una anaconda.

## Paul Rosolie fracasa en el reto de dejarse engullir por una anaconda

Comentar

El capítulo se emitió a pesar de las numerosas críticas que se oponían y, como era de esperar, no...

### Así son los ángeles de ´Todo va bien´

Edurne, Marbelys Zamora, María Lama y Berta Collado se calzan las alas de ángeles y protagonizan...

### Telemadrid une los logos de ETA, Podemos y Sortu en un informativo

La cadena pública vuelve a emitir un polémico grafismo con el logo de la formación de Iglesias...

### Frank Cuesta: ´Es jodido aguantar consejitos´

Seis meses después de que Yuyee entrara en la cárcel, dice que "no pinta que esto va a cambiar muy...

### Las ´salidas del armario´ más mediáticas

Oriol Nolis ha sido el último de los presentadores de televisión que ha hecho pública su...

### ´La que se avecina´ triunfa con el Mandanga Style y Ernesto Sevilla Dj

La comunidad de vecinos más alocada de la televisión logró tres trending topic gracias al...

Todas las noticias de Televisión
Imagen del reportero con una anaconda.

## Paul Rosolie fracasa en el reto de dejarse engullir por una anaconda

Comentar

El capítulo se emitió a pesar de las numerosas críticas que se oponían y, como era de esperar, no...

### Así son los ángeles de ´Todo va bien´

Edurne, Marbelys Zamora, María Lama y Berta Collado se calzan las alas de ángeles y protagonizan...

### Telemadrid une los logos de ETA, Podemos y Sortu en un informativo

La cadena pública vuelve a emitir un polémico grafismo con el logo de la formación de Iglesias...

### Frank Cuesta: ´Es jodido aguantar consejitos´

Seis meses después de que Yuyee entrara en la cárcel, dice que "no pinta que esto va a cambiar muy...

### Las ´salidas del armario´ más mediáticas

Oriol Nolis ha sido el último de los presentadores de televisión que ha hecho pública su...

### ´Gran Hermano 15´: Tras su expulsión, Juanma confiesa que tiene novia

'El primo' confesó en 'El Debate' que él también tiene una amiga especial fuera con la que lleva...

Todas las noticias de Televisión
Michelle Jenner como la Reina Isabel I de Castilla.

## Grandiosa Isabel

Comentar

Jordi Frades ha dirigido una historia apasionante contando con un equipo artístico de primera

### Sinvergüenzas

En este rincón no se va a hablar de sinvergüenzas al uso. Hablemos de otro sinvergüenza, hablemos...

### Rótulos en el telediario

¿Qué pasa cuando un rótulo presenta en TVE a Tania Sánchez como "Compañera sentimental de Pablo...

### Puto país

La tele va a lo suyo, y le importa una mierda el libro de Mariló, los libros en general...

### Desmiéntemelo

´Zapeando´ comenzó como los bebés, gateando, debilucho? pero al final acabó fortalecido

### Iñigo Errejón

Tiene cara de crío, es verdad, pero esa cara y su cuerpecillo de aguja se desvanecen como la bruma...

Todas las noticias de Televisión
Amador y Teodro en el último capítulo de 'LQSA'.

## ´La que se avecina´ triunfa con el Mandanga Style y Ernesto Sevilla Dj

Comentar

La comunidad de vecinos más alocada de la televisión logró tres trending topic gracias al...

### ´Los Simpson´ rinden un peculiar homenaje a la película ´Frozen´

La familia más famosa de la televisión ha preparado una divertida 'intro' navideña sobre la...

### Carlton Cuse: ´´Lost´ hizo posible que los guionistas rompieran las reglas´

El productor y guionista, artífice de la mítica serie, se embarca ahora en 'The Strain', apuesta...

### Scott Gimple defiende las muertes en ´The Walking Dead´

El 'showrunner' de la ficción asegura, tras el episodio de 'Coda', que "en esta serie pasan muchos...

### El creador de ´Sons of Anarchy´ difunde spoilers del final de la serie

Kurt Sutter manda por error a clientes y distribuidores, antes de emitirse el último capítulo, un...

### ´Black Mirror´: Tráiler del capítulo especial de Navidad

La serie contará con un capítulo especial de navidad en el que se relatará tres historias...

Todas las noticias de Televisión

- Noticias
- Programación
- Críticas TV
- Series

Ofertas de empleo en Pontevedra
Categorías:
Provincia:
Canal Celta
Celta de Vigo
El Equipo y toda la información de la plantilla del equipo. Opine y haga haga su once. FARO con el Celta.
más »

## Multimedia Galerías de Fotos Vídeos

## Participación

## Servicios

CANAL »
Noticias de empresa
Información sobre tu negocio

CANALES »
Canal Méteo
El tiempo en tu localidad

CONCURSO »
Imagen vacaciones
El concurso del verano

SERVICIOS »
Buzón de sugerencias
Contacta con FARO DE VIGO

OCIO »
Todos los eventos de Vigo
Consulta nuestra agenda!

ESPECIAL »
A Escola do FARO
Información sobre educación

### Humor Otras viñetas

### Edición impresa

##### Las portadas de hoy:

- Edición Vigo
- Edición O Morrazo
- Edición Deza-Tabeirós-Montes
- Edición Arousa
- Edición Pontevedra
- Edición Ourense

### Suplementos

##### Visítalos:

- Magazine
- Visado
- Faro Cultura
- Estela
- El Sábado

vuelos - vuelos baratos vigo

Lo último | Lo más leído

1. Un sondeo otorga al PSOE un 27%, por un 25% para Podemos y un 20% para el PP
2. Interceptan en Rande a un menor al volante de un coche con su padre ebrio de copiloto
3. La mayoría de los catalanes cree que el plan separatista será perjudicial para su economía
4. Desactivan un artefacto explosivo próximo a un concesionario de coches en el polígono de Barreiros
5. Fomento congela los peajes en las autopistas AP-9 y AP-53 tras cinco años de subidas
6. Diez grados y en bañador
7. Cuidado con el WhatsApp... paterno
8. Cuntis y Rianxo despiden a los dos obreros que murieron al volcarles la grúa en Valga
9. Los cruceristas suspenden la información que reciben de Vigo a bordo y en tierra
10. El cocinero del "Elcano", nexo de dos grupos que embarcaron 152 kilos de coca en el buque escuela

1. Basilea y Mónaco dejan fuera a Liverpool y Zenit
2. Simeone: "Buscamos lo que nos convenía"
3. Ancelotti: "No podía imaginar ganar 19 partidos seguidos"
4. La web The Pirate Bay, caída tras una redada policial
5. Cinco hijos de Ruiz-Mateos, condenados a pagar 5 millones
6. La dirección de Podemos coloca listas afines en Vigo, Ourense, A Coruña y Ferrol
7. Uber mantendrá sus servicios en España pese al fallo
8. Así torturaba la CIA a los supuestos terroristas
9. Chanel convierte a Pharrell Williams en Sisí Emperatriz
10. Scotland Yard vende su sede en Londres a un fondo de Abu Dhabi

## Canales y Servicios

### SERVICIOS

#### Argos

Servicio para agencias de publicidad

### PORTAL CELTA

#### Portal Celta de Vigo

Todas las noticias sobre el Celta. Propón tu alineación!

### CLUB FARO

Toda la programación con los conferenciantes del Club Faro

### ESPECIALES FARO

#### Especiales temáticos

Descubre la más variada información en profunidad

### ESPECIAL TURISMO

#### Descubriendo España

Repasa los rincones más atractivos para visitar en España

### SERVICIOS

#### Webcams

Consulta en directo cámaras repartidas por toda Galicia

## Especiales destacados

### LOTERÍA DE NAVIDAD

El próximo 22 de Diciembre sigue en directo el sorteo de navidad.

- Anécdotas
- Directo
- Pedrea

- Lugares Agraciados
- Comprobar lotería
- Lotería del Niño

### FÓRMULA 1

#### Fórmula 1 2014

Vive el mundial de Formula 1 y mantente informado con las últimas noticias de actualidad.

- Fórmula 1
- Fernando Alonso
- Calendario F1

- Directo
- Clasificación
- Pilotos

### FARODEVIGO.ES EN LAS REDES SOCIALES

- Videos
- Participación
- Foros

- Vida y estilo
- Encuestas
- Blogs

Enlaces recomendados: Oscars | Premios Goya
Mapa web
Gran Vigo

- Galicia
- Ocio en Vigo
- El tiempo
- Tráfico en Vigo
- Cartelera de cine
- Celta de Vigo

Clasificados

- Iberpisos
- Iberanuncio
- Ibercoches
- Iberempleo

Especiales

- Lotería de Navidad
- Lotería el Niño
- Fórmula 1
- Premios Oscar
- Canal Esquí
- Premios Goya

farodevigo.es

- Contacto
- Conozcanos
- Localización
- Club Faro de Vigo
- Aviso legal
- Política de cookies
- RSS

Publicidad

- Tarifas
- Contratar

Otras webs del Grupo Editorial Prensa Ibérica
Diari de Girona | Diario de Ibiza | Diario de Mallorca | Empordà | Faro de Vigo | Información | La Opinión A Coruña | La Opinión de Málaga | La Opinión de Murcia | La Opinión de Tenerife | La Opinión de Zamora | La Provincia | La Nueva España | Levante-EMV | Mallorca Zeitung | Regió 7 | Superdeporte | The Adelaide Review | 97.7 La Radio | Euroresidentes | Lotería de Navidad | Oscars | Premios Goya
Faro de Vigo